package com.bsdenterprise.flutter_mqtt_plugin.utilities;

import com.amazonaws.services.iot.client.AWSIotConnectionStatus;
import com.amazonaws.services.iot.client.AWSIotException;
import com.amazonaws.services.iot.client.AWSIotMqttClient;
import com.amazonaws.services.iot.client.AWSIotTimeoutException;
import com.bsdenterprise.flutter_mqtt_plugin.utilities.AWSIotMqttUtil.KeyStorePasswordPair;

import android.util.Log;
import java.util.UUID;

public class MqttClient extends AWSIotMqttClient {

    private MqttCallback callback;
    private long timeout;
    private boolean blocking;

    public MqttClient(String clientEndpoint, KeyStorePasswordPair pair, MqttCallback callback) {
        super(clientEndpoint, UUID.randomUUID().toString(), pair.keyStore, pair.keyPassword);
        this.setConnectionTimeout(40000);
        this.setMaxConnectionRetries(10);
        this.setKeepAliveInterval(40000);
        this.setServerAckTimeout(4000);
        this.timeout = 5000;
        this.blocking = false;
        this.callback = callback;
    }

    public void connectMqtt() {
        try {
            super.connect(this.timeout, this.blocking);
        } catch (AWSIotException e) {
            Log.e("AWSIotException", e.getMessage());
        } catch (AWSIotTimeoutException e) {
            Log.e("AWSIotTimeoutException", e.getMessage());
        }
    }

    public void disconnectMqtt() {
        if (this.getConnection().getConnectionStatus().equals(AWSIotConnectionStatus.CONNECTED)) {
            try {
                this.getConnection().disconnect(null);
            } catch (AWSIotException e) {
                Log.e("AWSIotException", e.getMessage());
            }
        }
    }

    @Override
    public void onConnectionSuccess() {
        this.callback.onConnectionSuccess();
    }

    @Override
    public void onConnectionFailure() {
        this.callback.onConnectionFailure();
    }

    @Override
    public void onConnectionClosed() {
        this.callback.onConnectionClosed();
    }
}
